pub unsafe fn wake_pin(pin: u8)Available on crate feature
unstable only.Expand description
Complete any in-flight async wait on a single GPIO pin.
Per-pin counterpart of handle_gpio_interrupt.
Safety
Must be called from a GPIO interrupt context.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.